@@ -277,7 +277,7 @@ void time_device (int fd)
 		TIMING_MB, elapsed, TIMING_MB / elapsed);
 
 	if (elapsed <= (correction * 2))
-		printf("Hmm.. suspicious results: probably not enough memory for a proper test.\n");
+		printf("Hmm.. suspicious results: probably not enough free memory for a proper test.\n");
 	else {
 		printf(" Estimating raw driver speed: ");
 		elapsed -= correction;
@@ -621,7 +621,7 @@ void process_dev (char *devname)
 
 void usage_error (void)
 {
-	fprintf(stderr,"%s - get/set hard disk parameters - version 2.1\n\n", progname);
+	fprintf(stderr,"%s - get/set hard disk parameters - version 2.2\n\n", progname);
 	fprintf(stderr,"Usage:  %s  [options] [device] ..\n\n", progname);
 	fprintf(stderr,"Options:\n");
 	fprintf(stderr," -a    get/set fs readahead\n");
@@ -649,7 +649,7 @@ void usage_error (void)
 #endif
 	fprintf(stderr," -t    perform device read timings\n");
 	fprintf(stderr," -u  * get/set unmaskirq flag (0/1) (DANGEROUS)\n");
-	fprintf(stderr," -v    (default) same as -agkmrsux (-agr for SCSI)\n");
+	fprintf(stderr," -v    (default) same as -agkmru (-agr for SCSI)\n");
 #ifdef HDIO_DRIVE_CMD
 	fprintf(stderr," -W  * set drive write-caching flag (0/1) (DANGEROUS)\n");
 	fprintf(stderr," -X  * set IDE xfer mode (DANGEROUS)\n");
